@@ -2,15 +2,15 @@
 #'
 #' @templateVar plans TRUE
 #' @templateVar shp TRUE
-#' @param use_Rcpp If `TRUE` (the default for more than 8 plans), precompute boundaries 
+#' @param use_Rcpp If `TRUE` (the default for more than 8 plans), precompute boundaries
 #'   shared by each pair of units and use them to quickly compute the compactness score.
-#' @param perim_path path to perimeter tibble saved by `prep_perims()`
-#' @param perim_df tibble of perimeters from `prep_perims()`
+#' @param perim_path Path to perimeter tibble saved by `prep_perims()`
+#' @param perim_df Tibble of perimeters from `prep_perims()`
 #' @templateVar epsg TRUE
 #' @templateVar ncores TRUE
 #' @template template
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept compactness
 #'
@@ -74,10 +74,10 @@ comp_polsby <- function(plans, shp, use_Rcpp, perim_path, perim_df, epsg = 3857,
   # calculate ----
   areas <- geos::geos_area(shp)
   if (use_Rcpp) {
-    splits <- split(x = plans, rep(1:nc, each = ceiling(n_plans / nc) * V)[1:(n_plans * V)]) %>%
+    splits <- split(x = plans, rep(seq_len(nc), each = ceiling(n_plans / nc) * V)[seq_len(n_plans * V)]) %>%
       lapply(., FUN = function(x, r = V) matrix(data = x, nrow = r))
 
-    result <- foreach::foreach(map = 1:nc, .combine = 'cbind', .packages = c('redistmetrics'),
+    result <- foreach::foreach(map = seq_len(nc), .combine = 'cbind', .packages = c('redistmetrics'),
                                .export = 'polsbypopper') %oper% {
       polsbypopper(
         from = perim_df$origin, to = perim_df$touching, area = areas,
@@ -85,11 +85,11 @@ comp_polsby <- function(plans, shp, use_Rcpp, perim_path, perim_df, epsg = 3857,
       )
     }
   } else {
-    result <- foreach::foreach(map = 1:n_plans, .combine = 'c', .packages = c('geos', 'redistmetrics'),
+    result <- foreach::foreach(map = seq_len(n_plans), .combine = 'c', .packages = c('geos', 'redistmetrics'),
                                .export = 'geox_union') %oper% {
       ret <- vector('numeric', nd)
 
-      for (i in 1:nd) {
+      for (i in seq_len(nd)) {
         united <- geox_union(geos::geos_geometry_n(shp_col, which(plans[, map] == dists[i])))
         area <- sum(areas[plans[, map] == dists[i]])
 
@@ -116,7 +116,7 @@ comp_polsby <- function(plans, shp, use_Rcpp, perim_path, perim_df, epsg = 3857,
 #' @templateVar ncores TRUE
 #' @template template
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept compactness
 #'
@@ -176,10 +176,10 @@ comp_schwartz <- function(plans, shp, use_Rcpp, perim_path, perim_df, epsg = 385
   # calculate ----
   areas <- geos::geos_area(shp)
   if (use_Rcpp) {
-    splits <- split(x = plans, rep(1:nc, each = ceiling(n_plans / nc) * V)[1:(n_plans * V)]) %>%
+    splits <- split(x = plans, rep(seq_len(nc), each = ceiling(n_plans / nc) * V)[seq_len(n_plans * V)]) %>%
       lapply(., FUN = function(x, r = V) matrix(data = x, nrow = r))
 
-    result <- foreach::foreach(map = 1:nc, .combine = 'cbind', .packages = c('redistmetrics'),
+    result <- foreach::foreach(map = seq_len(nc), .combine = 'cbind', .packages = c('redistmetrics'),
                                .export = 'schwartzberg') %oper% {
       schwartzberg(
         from = perim_df$origin, to = perim_df$touching, area = areas,
@@ -187,11 +187,11 @@ comp_schwartz <- function(plans, shp, use_Rcpp, perim_path, perim_df, epsg = 385
       )
     }
   } else {
-    result <- foreach::foreach(map = 1:n_plans, .combine = 'c', .packages = c('geos'),
+    result <- foreach::foreach(map = seq_len(n_plans), .combine = 'c', .packages = c('geos'),
                                .export = 'geox_union') %oper% {
       ret <- vector('numeric', nd)
 
-      for (i in 1:nd) {
+      for (i in seq_len(nd)) {
         united <- geox_union(geos::geos_geometry_n(shp_col, which(plans[, map] == dists[i])))
         area <- sum(areas[plans[, map] == dists[i]])
 
@@ -215,7 +215,7 @@ comp_schwartz <- function(plans, shp, use_Rcpp, perim_path, perim_df, epsg = 385
 #' @templateVar ncores TRUE
 #' @template template
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept compactness
 #'
@@ -259,12 +259,12 @@ comp_reock <- function(plans, shp, epsg = 3857, ncores = 1) {
 
   # compute ----
   areas <- geos::geos_area(shp)
-  out <- foreach::foreach(map = 1:n_plans, .combine = 'c', .packages = c('geos'),
+  out <- foreach::foreach(map = seq_len(n_plans), .combine = 'c', .packages = c('geos'),
                           .export = 'geox_union') %oper% {
     ret <- vector('numeric', nd)
 
-    for (i in 1:nd) {
-      united <- geox_union(geos::geos_geometry_n(shp_col, which(plans[, map] == dists[i])))
+    for (i in seq_len(nd)) {
+      united <- geos::geos_make_collection(geos::geos_geometry_n(shp_col, which(plans[, map] == dists[i])))
       area <- sum(areas[plans[, map] == dists[i]])
 
       mbc <- geos::geos_area(geos::geos_minimum_bounding_circle(united))
@@ -285,7 +285,7 @@ comp_reock <- function(plans, shp, epsg = 3857, ncores = 1) {
 #' @templateVar ncores TRUE
 #' @template template
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept compactness
 #'
@@ -325,12 +325,12 @@ comp_ch <- function(plans, shp, epsg = 3857, ncores = 1) {
 
   # compute ----
   areas <- geos::geos_area(shp)
-  out <- foreach::foreach(map = 1:n_plans, .combine = 'c', .packages = c('geos'),
+  out <- foreach::foreach(map = seq_len(n_plans), .combine = 'c', .packages = c('geos'),
                           .export = 'geox_union') %oper% {
     ret <- vector('numeric', nd)
 
-    for (i in 1:nd) {
-      united <- geox_union(geos::geos_geometry_n(shp_col, which(plans[, map] == dists[i])))
+    for (i in seq_len(nd)) {
+      united <- geos::geos_make_collection(geos::geos_geometry_n(shp_col, which(plans[, map] == dists[i])))
       area <- sum(areas[plans[, map] == dists[i]])
 
       cvh <- geos::geos_area(geos::geos_convex_hull(united))
@@ -351,7 +351,7 @@ comp_ch <- function(plans, shp, epsg = 3857, ncores = 1) {
 #' @templateVar ncores TRUE
 #' @template template
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept compactness
 #'
@@ -394,9 +394,9 @@ comp_lw <- function(plans, shp, epsg = 3857, ncores = 1) {
   shp <- geos::as_geos_geometry(shp)
   # compute ----
   bboxes <- as.matrix(geos::geos_envelope_rct(shp))
-  result <- foreach::foreach(map = 1:n_plans, .combine = 'cbind') %oper% {
+  result <- foreach::foreach(map = seq_len(n_plans), .combine = 'cbind') %oper% {
     out <- numeric(nd)
-    for (i in 1:nd) {
+    for (i in seq_len(nd)) {
       idx <- plans[, map] == dists[i]
       xdiff <- max(bboxes[idx, 3]) - min(bboxes[idx, 1])
       ydiff <- max(bboxes[idx, 4]) - min(bboxes[idx, 2])
@@ -416,7 +416,7 @@ comp_lw <- function(plans, shp, epsg = 3857, ncores = 1) {
 #' @templateVar ncores TRUE
 #' @template template
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept compactness
 #'
@@ -463,11 +463,11 @@ comp_bc <- function(plans, shp, epsg = 3857, ncores = 1) {
   }
 
   # compute ----
-  result <- foreach::foreach(map = 1:n_plans, .combine = 'cbind', .packages = c('geos'),
+  result <- foreach::foreach(map = seq_len(n_plans), .combine = 'cbind', .packages = c('geos'),
                              .export = c('geox_union', 'geox_coordinates')) %oper% {
     out <- numeric(nd)
 
-    for (i in 1:nd) {
+    for (i in seq_len(nd)) {
       united <- geox_union(geos::geos_geometry_n(shp_col, which(plans[, map] == dists[i])))
       center <- geos::geos_centroid(united)
       if (!geos::geos_within(united, center)) {
@@ -503,7 +503,7 @@ comp_bc <- function(plans, shp, epsg = 3857, ncores = 1) {
 #' @param ncores TRUE
 #' @template template
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept compactness
 #'
@@ -535,7 +535,7 @@ comp_fh <- function(plans, shp, total_pop, epsg = 3857, ncores = 1) {
   pop <- total_pop * t(matrix(rep(total_pop, length(shp)), length(shp)))
   fh <- pop * dist_sqr
   out <- apply(plans, 2, function(x) {
-    sum(vapply(1:nd, function(i) {
+    sum(vapply(seq_len(nd), function(i) {
       ind <- x == i
       sum(fh[ind, ind])
     },
@@ -553,7 +553,7 @@ comp_fh <- function(plans, shp, total_pop, epsg = 3857, ncores = 1) {
 #' @templateVar adj TRUE
 #' @template template
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept compactness
 #'
@@ -582,8 +582,7 @@ comp_edges_rem <- function(plans, shp, adj) {
     cli::cli_abort('{.arg adj} missing and {.arg shp} is not a {.cls redist_map}.')
   }
 
-  n_removed(g = adj, districts = plans, n_distr = nd) %>%
-    rep(each = nd)
+  rep(n_removed(g = adj, districts = plans, n_distr = nd), each=nd)
 }
 
 #' Calculate Fraction Kept Compactness
@@ -593,7 +592,7 @@ comp_edges_rem <- function(plans, shp, adj) {
 #' @templateVar adj TRUE
 #' @template template
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept compactness
 #'
@@ -623,8 +622,7 @@ comp_frac_kept <- function(plans, shp, adj) {
   }
   n_edge <- length(unlist(adj))
 
-  (1 - (n_removed(g = adj, districts = plans, n_distr = nd) / n_edge)) %>%
-    rep(each = nd)
+  rep(1 - (n_removed(g = adj, districts = plans, n_distr = nd) / n_edge), each=nd)
 }
 
 #' Calculate Log Spanning Tree Compactness
@@ -635,7 +633,7 @@ comp_frac_kept <- function(plans, shp, adj) {
 #' @templateVar adj TRUE
 #' @template template
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept compactness
 #'
@@ -670,8 +668,7 @@ comp_log_st <- function(plans, shp, counties = NULL, adj) {
     cli::cli_abort('{.arg adj} missing and {.arg shp} is not a {.cls redist_map}.')
   }
 
-  log_st_map(g = adj, districts = plans, counties = counties, n_distr = nd) %>%
-    rep(each = nd)
+  rep(log_st_map(g = adj, districts = plans, counties = counties, n_distr = nd), each=nd)
 }
 
 #' Calculate Skew Compactness
@@ -686,7 +683,7 @@ comp_log_st <- function(plans, shp, counties = NULL, adj) {
 #' @templateVar ncores TRUE
 #' @template template
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept compactness
 #'
@@ -731,11 +728,11 @@ comp_skew <- function(plans, shp, epsg = 3857, ncores = 1) {
   }
 
   # compute ----
-  result <- foreach::foreach(map = 1:n_plans, .combine = 'cbind', .packages = c('geos'),
+  result <- foreach::foreach(map = seq_len(n_plans), .combine = 'cbind', .packages = c('geos'),
                              .export = 'geox_union') %oper% {
     out <- numeric(nd)
 
-    for (i in 1:nd) {
+    for (i in seq_len(nd)) {
       united <- geox_union(geos::geos_geometry_n(shp_col, which(plans[, map] == dists[i])))
       w <- sqrt(geos::geos_area(geos::geos_maximum_inscribed_crc(united, tolerance = 0.01)))
       l <- sqrt(geos::geos_area(geos::geos_minimum_bounding_circle(united)))
@@ -760,7 +757,7 @@ comp_skew <- function(plans, shp, epsg = 3857, ncores = 1) {
 #' @templateVar ncores TRUE
 #' @template template
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept compactness
 #'
@@ -803,12 +800,12 @@ comp_box_reock <- function(plans, shp, epsg = 3857, ncores = 1) {
   # compute ----
 
   areas <- geos::geos_area(shp)
-  out <- foreach::foreach(map = 1:n_plans, .combine = 'c', .packages = c('geos'),
+  out <- foreach::foreach(map = seq_len(n_plans), .combine = 'c', .packages = c('geos'),
                           .export = 'geox_union') %oper% {
     ret <- vector('numeric', nd)
 
-    for (i in 1:nd) {
-      united <- geox_union(geos::geos_geometry_n(shp_col, which(plans[, map] == dists[i])))
+    for (i in seq_len(nd)) {
+      united <- geos::geos_make_collection(geos::geos_geometry_n(shp_col, which(plans[, map] == dists[i])))
       area <- sum(areas[plans[, map] == dists[i]])
 
       mbc <- geos::geos_area(geos::geos_minimum_rotated_rectangle(united))
@@ -832,7 +829,7 @@ comp_box_reock <- function(plans, shp, epsg = 3857, ncores = 1) {
 #' @templateVar ncores TRUE
 #' @template template
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept compactness
 #'
@@ -879,11 +876,11 @@ comp_y_sym <- function(plans, shp, epsg = 3857, ncores = 1) {
 
   areas <- geos::geos_area(shp)
   coords <- geox_coordinates(geos::geos_centroid(shp))
-  out <- foreach::foreach(map = 1:n_plans, .combine = 'c', .packages = c('geos'),
+  out <- foreach::foreach(map = seq_len(n_plans), .combine = 'c', .packages = c('geos'),
                           .export = c('geox_union', 'geox_sub_centroid')) %oper% {
     ret <- vector('numeric', nd)
 
-    for (i in 1:nd) {
+    for (i in seq_len(nd)) {
       w_prec <- which(plans[, map] == dists[i])
       # find centroid
       cent <- geox_sub_centroid(coords, areas, w_prec)
@@ -892,10 +889,18 @@ comp_y_sym <- function(plans, shp, epsg = 3857, ncores = 1) {
       #coords_ctr <- coords[w_prec, ] - cent
       # need to do affine transformations in sf for now?
       shp_ctr <- sf::st_union(shp[w_prec] - cent)
-      shp_refl <- sf::st_coordinates(shp_ctr)[, 1:2]
-      shp_refl[, 1] <- shp_refl[, 1] * -1
-      shp_refl <- sf::st_sfc(sf::st_polygon(list(shp_refl)))
+      coords_ctr <- sf::st_coordinates(shp_ctr)
+      shp_refl <- coords_ctr[, 1:2]
 
+      if (!all(shp_refl[1, ] == shp_refl[nrow(shp_refl), ])) {
+        shp_refl[, 1] <- shp_refl[, 1] * -1
+        shp_refl <- sf::st_sfc(sf::st_polygon(
+          lapply(unique(coords_ctr[, 3]), function(x) shp_refl[coords_ctr[, 3] == x, ])
+        ))
+      } else {
+        shp_refl[, 1] <- shp_refl[, 1] * -1
+        shp_refl <- sf::st_sfc(sf::st_polygon(list(shp_refl)))
+      }
 
       # Reflect over x = 0 and make shapes
       # the idea, but needs to be the actual shapes, not the centers:
@@ -931,7 +936,7 @@ comp_y_sym <- function(plans, shp, epsg = 3857, ncores = 1) {
 #' @templateVar ncores TRUE
 #' @template template
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept compactness
 #'
@@ -981,11 +986,11 @@ comp_x_sym <- function(plans, shp, epsg = 3857, ncores = 1) {
   ## experimental:
   #all_pts <- wk::wk_coords(shp)
 
-  out <- foreach::foreach(map = 1:n_plans, .combine = 'c', .packages = c('geos'),
+  out <- foreach::foreach(map = seq_len(n_plans), .combine = 'c', .packages = c('geos'),
                           .export = c('geox_union', 'geox_sub_centroid')) %oper% {
     ret <- vector('numeric', nd)
 
-    for (i in 1:nd) {
+    for (i in seq_len(nd)) {
       w_prec <- which(plans[, map] == dists[i])
 
       # # experimental:
@@ -995,9 +1000,18 @@ comp_x_sym <- function(plans, shp, epsg = 3857, ncores = 1) {
 
       # center at 0, 0
       shp_ctr <- sf::st_union(shp[w_prec] - cent)
-      shp_refl <- sf::st_coordinates(shp_ctr)[, 1:2]
-      shp_refl[, 2] <- shp_refl[, 2] * -1
-      shp_refl <- sf::st_sfc(sf::st_polygon(list(shp_refl)))
+      coords_ctr <- sf::st_coordinates(shp_ctr)
+      shp_refl <- coords_ctr[, 1:2]
+
+      if (!all(shp_refl[1, ] == shp_refl[nrow(shp_refl), ])) {
+        shp_refl[, 2] <- shp_refl[, 2] * -1
+        shp_refl <- sf::st_sfc(sf::st_polygon(
+          lapply(unique(coords_ctr[, 3]), function(x) shp_refl[coords_ctr[, 3] == x, ])
+        ))
+      } else {
+        shp_refl[, 2] <- shp_refl[, 2] * -1
+        shp_refl <- sf::st_sfc(sf::st_polygon(list(shp_refl)))
+      }
 
       # # experimental:
       # # center at 0,0
