@@ -7,7 +7,7 @@
 #' @param v vote share to calculate bias at. Numeric. Default is 0.5.
 #' @template template_nosf
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept partisan
 #'
@@ -61,7 +61,7 @@ part_bias <- function(plans, shp, dvote, rvote, v = 0.5) {
 #' @templateVar rvote TRUE
 #' @template template_nosf
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept partisan
 #'
@@ -97,7 +97,7 @@ part_dseats <- function(plans, shp, dvote, rvote) {
   nd <- length(unique(plans[, 1]))
   rcounts <- agg_p2d(vote = rvote, dm = plans, nd = nd)
   dcounts <- agg_p2d(vote = dvote, dm = plans, nd = nd)
-  dseat_vec <- dseats(dm = plans, rcounts = rcounts, dcounts = dcounts, nd = nd)
+  dseat_vec <- dseats(rcounts = rcounts, dcounts = dcounts)
 
   rep(dseat_vec, each = nd)
 }
@@ -111,7 +111,7 @@ part_dseats <- function(plans, shp, dvote, rvote) {
 #' @templateVar rvote TRUE
 #' @template template_nosf
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept partisan
 #'
@@ -158,7 +158,7 @@ part_dvs <- function(plans, shp, dvote, rvote) {
 #' @templateVar rvote TRUE
 #' @template template_nosf
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept partisan
 #'
@@ -211,7 +211,7 @@ part_egap <- function(plans, shp, dvote, rvote) {
 #' @templateVar rvote TRUE
 #' @template template_nosf
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept partisan
 #'
@@ -251,7 +251,7 @@ part_egap_ep <- function(plans, shp, dvote, rvote) {
   nd <- length(unique(plans[, 1]))
   rcounts <- agg_p2d(vote = rvote, dm = plans, nd = nd)
   dcounts <- agg_p2d(vote = dvote, dm = plans, nd = nd)
-  dseat_vec <- dseats(dm = plans, rcounts = rcounts, dcounts = dcounts, nd = nd)
+  dseat_vec <- dseats(rcounts = rcounts, dcounts = dcounts)
   dvs <- DVS(dcounts = dcounts, rcounts = rcounts)
 
   rep(effgapEP(dvs = dvs, dseat_vec = dseat_vec, nd = nd), each = nd)
@@ -266,7 +266,7 @@ part_egap_ep <- function(plans, shp, dvote, rvote) {
 #' @param tau A non-negative numeric for calculating Tau Gap. Defaults to 1.
 #' @template template_nosf
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept partisan
 #'
@@ -305,14 +305,9 @@ part_tau_gap <- function(plans, shp, dvote, rvote, tau = 1) {
   nd <- length(unique(plans[, 1]))
   rcounts <- agg_p2d(vote = rvote, dm = plans, nd = nd)
   dcounts <- agg_p2d(vote = dvote, dm = plans, nd = nd)
-  dseat_vec <- dseats(dm = plans, rcounts = rcounts, dcounts = dcounts, nd = nd)
+  dseat_vec <- dseats(rcounts = rcounts, dcounts = dcounts)
   dvs <- DVS(dcounts = dcounts, rcounts = rcounts)
 
-  cli::cli_inform(
-    '{.pkg redistmetrics} 1.0.2 reverses tau gap direction. Positive is now pro-Republican bias.',
-    .frequency = 'once', .frequency_id = 'tau_gap'
-  )
-
   rep(taugap(tau = tau, dvs = dvs, dseat_vec = dseat_vec, nd = nd), each = nd)
 }
 
@@ -324,7 +319,7 @@ part_tau_gap <- function(plans, shp, dvote, rvote, tau = 1) {
 #' @templateVar rvote TRUE
 #' @template template_nosf
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept partisan
 #'
@@ -380,7 +375,7 @@ part_mean_median <- function(plans, shp, dvote, rvote) {
 #' @param adjust Default is TRUE. Applies a correction to increase cross-size comparison.
 #' @template template_nosf
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept partisan
 #'
@@ -419,7 +414,7 @@ part_decl <- function(plans, shp, dvote, rvote, normalize = TRUE, adjust = TRUE)
   nd <- length(unique(plans[, 1]))
   rcounts <- agg_p2d(vote = rvote, dm = plans, nd = nd)
   dcounts <- agg_p2d(vote = dvote, dm = plans, nd = nd)
-  dseat_vec <- dseats(dm = plans, rcounts = rcounts, dcounts = dcounts, nd = nd)
+  dseat_vec <- dseats(rcounts = rcounts, dcounts = dcounts)
   dvs <- DVS(dcounts = dcounts, rcounts = rcounts)
 
   dec <- declination_angle(dvs = dvs, dseat_vec = dseat_vec, nd = nd)
@@ -443,7 +438,7 @@ part_decl <- function(plans, shp, dvote, rvote, normalize = TRUE, adjust = TRUE)
 #' @templateVar rvote TRUE
 #' @template template_nosf
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept partisan
 #'
@@ -483,7 +478,7 @@ part_decl_simple <- function(plans, shp, dvote, rvote) {
   nd <- length(unique(plans[, 1]))
   rcounts <- agg_p2d(vote = rvote, dm = plans, nd = nd)
   dcounts <- agg_p2d(vote = dvote, dm = plans, nd = nd)
-  dseat_vec <- dseats(dm = plans, rcounts = rcounts, dcounts = dcounts, nd = nd)
+  dseat_vec <- dseats(rcounts = rcounts, dcounts = dcounts)
   dvs <- DVS(dcounts = dcounts, rcounts = rcounts)
 
   declination_simple(dvs = dvs, dseat_vec = dseat_vec, nd = nd) %>%
@@ -501,7 +496,7 @@ part_decl_simple <- function(plans, shp, dvote, rvote) {
 #' @param bandwidth Defaults to 0.01. A value between 0 and 1 for the step size to estimate the slope.
 #' @template template_nosf
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept partisan
 #'
@@ -541,7 +536,7 @@ part_resp <- function(plans, shp, dvote, rvote, v = 0.5, bandwidth = 0.01) {
   nd <- length(unique(plans[, 1]))
   rcounts <- agg_p2d(vote = rvote, dm = plans, nd = nd)
   dcounts <- agg_p2d(vote = dvote, dm = plans, nd = nd)
-  dseat_vec <- dseats(dm = plans, rcounts = rcounts, dcounts = dcounts, nd = nd)
+  dseat_vec <- dseats(rcounts = rcounts, dcounts = dcounts)
   dvs <- DVS(dcounts = dcounts, rcounts = rcounts)
 
   rep(responsiveness(dvs = dvs, v = v, nd = nd, bandwidth = bandwidth), each = nd)
@@ -555,7 +550,7 @@ part_resp <- function(plans, shp, dvote, rvote, v = 0.5, bandwidth = 0.01) {
 #' @templateVar rvote TRUE
 #' @template template_nosf
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept partisan
 #'
@@ -594,7 +589,7 @@ part_lop_wins <- function(plans, shp, dvote, rvote) {
   nd <- length(unique(plans[, 1]))
   rcounts <- agg_p2d(vote = rvote, dm = plans, nd = nd)
   dcounts <- agg_p2d(vote = dvote, dm = plans, nd = nd)
-  dseat_vec <- dseats(dm = plans, rcounts = rcounts, dcounts = dcounts, nd = nd)
+  dseat_vec <- dseats(rcounts = rcounts, dcounts = dcounts)
   dvs <- DVS(dcounts = dcounts, rcounts = rcounts)
 
   rep(lopsidedwins(dvs = dvs, dseat_vec = dseat_vec, nd = nd), each = nd)
@@ -608,7 +603,7 @@ part_lop_wins <- function(plans, shp, dvote, rvote) {
 #' @templateVar rvote TRUE
 #' @template template_nosf
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept partisan
 #'
@@ -661,7 +656,7 @@ part_rmd <- function(plans, shp, dvote, rvote) {
 #' @templateVar rvote TRUE
 #' @template template_nosf
 #'
-#' @return numeric vector
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
 #' @export
 #' @concept partisan
 #'
