@@ -40,3 +40,14 @@ test_that("splits_count works", {
                  .Dim = c(10L, 2L))
   expect_equal(a, e, tolerance = 1e-4)
 })
+
+
+test_that("splits_total works", {
+  a <- splits_total(nh$r_2020, nh, county)
+  e <- c(6, 6)
+  expect_equal(a, e, tolerance = 1e-4)
+
+  a <- splits_total(nh_m[, 1:2], nh, county)
+  e <- c(5, 5, 6, 6)
+  expect_equal(a, e, tolerance = 1e-4)
+})
